# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.wav.v20210129 import models


class WavClient(AbstractClient):
    _apiVersion = '2021-01-29'
    _endpoint = 'wav.tencentcloudapi.com'
    _service = 'wav'


    def CreateChannelCode(self, request):
        """新增渠道活码接口

        :param request: Request instance for CreateChannelCode.
        :type request: :class:`tencentcloud.wav.v20210129.models.CreateChannelCodeRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.CreateChannelCodeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateChannelCode", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateChannelCodeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateCorpTag(self, request):
        """该接口用户设置标签库, 每个企业最多可配置3000个企业标签。

        :param request: Request instance for CreateCorpTag.
        :type request: :class:`tencentcloud.wav.v20210129.models.CreateCorpTagRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.CreateCorpTagResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateCorpTag", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateCorpTagResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryActivityJoinList(self, request):
        """根据游标拉取活动参与列表信息

        :param request: Request instance for QueryActivityJoinList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryActivityJoinListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryActivityJoinListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryActivityJoinList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryActivityJoinListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryActivityList(self, request):
        """根据游标拉取活动列表信息

        :param request: Request instance for QueryActivityList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryActivityListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryActivityListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryActivityList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryActivityListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryActivityLiveCodeList(self, request):
        """根据游标拉取活动活码列表信息

        :param request: Request instance for QueryActivityLiveCodeList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryActivityLiveCodeListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryActivityLiveCodeListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryActivityLiveCodeList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryActivityLiveCodeListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryChannelCodeList(self, request):
        """根据游标拉取渠道活码列表信息

        :param request: Request instance for QueryChannelCodeList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryChannelCodeListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryChannelCodeListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryChannelCodeList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryChannelCodeListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryChatArchivingList(self, request):
        """根据游标拉取会话存档列表信息

        :param request: Request instance for QueryChatArchivingList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryChatArchivingListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryChatArchivingListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryChatArchivingList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryChatArchivingListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryClueInfoList(self, request):
        """企业可通过此接口获取线索列表。

        :param request: Request instance for QueryClueInfoList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryClueInfoListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryClueInfoListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryClueInfoList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryClueInfoListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryExternalContactDetail(self, request):
        """企业可通过此接口，根据外部联系人的userid，拉取客户详情

        :param request: Request instance for QueryExternalContactDetail.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryExternalContactDetailRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryExternalContactDetailResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryExternalContactDetail", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryExternalContactDetailResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryExternalContactList(self, request):
        """企业可通过此接口获取指定成员添加的客户列表。客户是指配置了客户联系功能的成员所添加的外部联系人。没有配置客户联系功能的成员，所添加的外部联系人将不会作为客户返回。

        :param request: Request instance for QueryExternalContactList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryExternalContactListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryExternalContactListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryExternalContactList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryExternalContactListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryExternalUserMappingInfo(self, request):
        """企业可通过此接口将企业主体对应的外部联系人id转换为乐销车应用主体对应的外部联系人。

        :param request: Request instance for QueryExternalUserMappingInfo.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryExternalUserMappingInfoRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryExternalUserMappingInfoResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryExternalUserMappingInfo", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryExternalUserMappingInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryLicenseInfo(self, request):
        """该接口获取license对应的详细信息

        :param request: Request instance for QueryLicenseInfo.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryLicenseInfoRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryLicenseInfoResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryLicenseInfo", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryLicenseInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryMiniAppCodeList(self, request):
        """查询小程序码列表接口

        :param request: Request instance for QueryMiniAppCodeList.
        :type request: :class:`tencentcloud.wav.v20210129.models.QueryMiniAppCodeListRequest`
        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryMiniAppCodeListResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryMiniAppCodeList", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryMiniAppCodeListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# API元数据解析失败。
FAILEDOPERATION_APIMETAPARSEFAILED = 'FailedOperation.ApiMetaParseFailed'

# 创建应用，获取ES鉴权信息失败。
FAILEDOPERATION_APPLICATIONCREATEESATUHERROR = 'FailedOperation.ApplicationCreateEsAtuhError'

# 应用查询失败。
FAILEDOPERATION_APPLICATIONQUERYFAILED = 'FailedOperation.ApplicationQueryFailed'

# 创建集群，开通VPC网络权限失败。
FAILEDOPERATION_CLUSTERCREATEVPCFAIL = 'FailedOperation.ClusterCreateVpcFail'

# 查询集群失败。
FAILEDOPERATION_CLUSTERQUERYFAILED = 'FailedOperation.ClusterQueryFailed'

# 应用查询失败。
FAILEDOPERATION_CONFIGAPPLICATIONQUERYFAILED = 'FailedOperation.ConfigApplicationQueryFailed'

# 配置项创建失败。
FAILEDOPERATION_CONFIGCREATEFAILED = 'FailedOperation.ConfigCreateFailed'

# 部署组查询失败。
FAILEDOPERATION_CONFIGGROUPQUERYFAILED = 'FailedOperation.ConfigGroupQueryFailed'

# 命名空间查询失败。
FAILEDOPERATION_CONFIGNAMESPACEQUERYFAILED = 'FailedOperation.ConfigNamespaceQueryFailed'

# 部署组处于运行状态，无法启动。
FAILEDOPERATION_CONTAINERGROUPGROUPHASRUN = 'FailedOperation.ContainergroupGroupHasrun'

# 部署组处于停止状态，无法执行此操作。
FAILEDOPERATION_CONTAINERGROUPGROUPHASSTOP = 'FailedOperation.ContainergroupGroupHasstop'

# 健康检查配置失败。
FAILEDOPERATION_CVMCAEMASTERHEALTHCHECKCONFIGERROR = 'FailedOperation.CvmCaeMasterHealthCheckConfigError'

# 远端访问错误: %s。
FAILEDOPERATION_GATEWAYREMOTECALLERROR = 'FailedOperation.GatewayRemoteCallError'

# 命名空间下存在部署组。
FAILEDOPERATION_GROUPEXISTS = 'FailedOperation.GroupExists'

# 部署组查询失败。
FAILEDOPERATION_GROUPQUERYFAILD = 'FailedOperation.GroupQueryFaild'

# 重装系统失败，请稍后重试。若无法解决，请联系智能客服或提交工单。
FAILEDOPERATION_INSTANCERESETERROR = 'FailedOperation.InstanceResetError'

# 重装系统，请求超时。
FAILEDOPERATION_INSTANCERESETTIMEOUT = 'FailedOperation.InstanceResetTimeout'

# 机器实例更新失败。
FAILEDOPERATION_INSTANCEUPDATEFAILED = 'FailedOperation.InstanceUpdateFailed'

# 泳道从consul删除失败。
FAILEDOPERATION_LANEINFODELETECONSULFAILED = 'FailedOperation.LaneInfoDeleteConsulFailed'

# 新增关联部署组不能为空。
FAILEDOPERATION_LANEINFOGROUPNOTEMPTY = 'FailedOperation.LaneInfoGroupNotEmpty'

# 泳道同步到consul失败。
FAILEDOPERATION_LANEINFORELEASECONSULFAILED = 'FailedOperation.LaneInfoReleaseConsulFailed'

# 泳道发布到mesh失败。
FAILEDOPERATION_LANEINFORELEASEMESHFAILED = 'FailedOperation.LaneInfoReleaseMeshFailed'

# 全链路灰度规则启用失败。
FAILEDOPERATION_LANERULEENABLECONSULFAILED = 'FailedOperation.LaneRuleEnableConsulFailed'

# 用户全链路灰度规则最大100条。
FAILEDOPERATION_LANERULEMAXLIMIT = 'FailedOperation.LaneRuleMaxLimit'

# 无法创建命名空间。
FAILEDOPERATION_NAMESPACECREATEFAILED = 'FailedOperation.NamespaceCreateFailed'

# 命名空间查询失败。
FAILEDOPERATION_NAMESPACEQUERYFAILED = 'FailedOperation.NamespaceQueryFailed'

# 访问配置中心失败。
FAILEDOPERATION_RATELIMITCONSULERROR = 'FailedOperation.RatelimitConsulError'

# 服务数据库入库失败。
FAILEDOPERATION_SERVICEINSERTFAILED = 'FailedOperation.ServiceInsertFailed'

# 服务查询失败。
FAILEDOPERATION_SERVICEQUERYFAILED = 'FailedOperation.ServiceQueryFailed'

# 任务创建异常。
FAILEDOPERATION_TASKCREATEERROR = 'FailedOperation.TaskCreateError'

# 任务删除异常。
FAILEDOPERATION_TASKDELETEERROR = 'FailedOperation.TaskDeleteError'

# 操作失败。
FAILEDOPERATION_TASKOPERATIONFAILED = 'FailedOperation.TaskOperationFailed'

# 禁止操作。
FAILEDOPERATION_TASKOPERATIONFORBIDDEN = 'FailedOperation.TaskOperationForbidden'

# 任务下发异常。
FAILEDOPERATION_TASKPUSHERROR = 'FailedOperation.TaskPushError'

# 任务查询异常。
FAILEDOPERATION_TASKQUERYERROR = 'FailedOperation.TaskQueryError'

# 停止任务失败。
FAILEDOPERATION_TASKTERMINATEFAILED = 'FailedOperation.TaskTerminateFailed'

# 任务更新异常。
FAILEDOPERATION_TASKUPDATEERROR = 'FailedOperation.TaskUpdateError'

# TKE 集群创建失败，%s。
FAILEDOPERATION_TKECLUSTERCREATEFAILED = 'FailedOperation.TkeClusterCreateFailed'

# TKE 集群查询失败。
FAILEDOPERATION_TKECLUSTERQUERYFAILED = 'FailedOperation.TkeClusterQueryFailed'

# resource服务错误。
FAILEDOPERATION_TSFASRESOURCESERVERERROR = 'FailedOperation.TsfAsResourceServerError'

# TSF权限模块异常，请联系系统管理员。。
FAILEDOPERATION_TSFPRIVILEGEERROR = 'FailedOperation.TsfPrivilegeError'

# 应用操作请求MASTER FEIGN失败。
INTERNALERROR_APPLICATIONMASTERFEIGNERROR = 'InternalError.ApplicationMasterFeignError'

# 应用操作请求MASTER 操作失败。
INTERNALERROR_APPLICATIONMASTERNUKNOWNERROR = 'InternalError.ApplicationMasterNuknownError'

# 删除应用程序包请求仓库失败。
INTERNALERROR_APPLICATIONREPODELETEPKG = 'InternalError.ApplicationRepoDeletePkg'

# 创建应用初始化tsf-scalable请求失败。
INTERNALERROR_APPLICATIONSCALABLEINITERROR = 'InternalError.ApplicationScalableInitError'

# TSF云API调用申请角色临时凭证调用请求失败。
INTERNALERROR_CAMROLEREQUESTERROR = 'InternalError.CamRoleRequestError'

# TSF云API请求调用失败。
INTERNALERROR_CLOUDAPIPROXYERROR = 'InternalError.CloudApiProxyError'

# 集群通用错误。
INTERNALERROR_CLUSTERCOMMONERROR = 'InternalError.ClusterCommonError'

# 虚拟机集群请求MASTER FEIGN失败。
INTERNALERROR_CLUSTERMASTERFEIGNERROR = 'InternalError.ClusterMasterFeignError'

# 无法找到部署组，或相应集群/命名空间/应用的权限不足。
INTERNALERROR_CLUSTERNOTEXISTORPRIVILEGEERROR = 'InternalError.ClusterNotExistOrPrivilegeError'

# 配置发布失败：配置中心服务器处理失败。
INTERNALERROR_CONSULSERVERERROR = 'InternalError.ConsulServerError'

# 访问TKE服务失败。
INTERNALERROR_CONTAINERGROUPKUBERNETEAPIINVOKEERROR = 'InternalError.ContainergroupKuberneteApiInvokeError'

# 连接TKE服务失败。
INTERNALERROR_CONTAINERGROUPKUBERNETECONNECTERROR = 'InternalError.ContainergroupKuberneteConnectError'

# 容器应用SQL错误。
INTERNALERROR_CONTAINERGROUPSQLFAILED = 'InternalError.ContainergroupSqlFailed'

# 容器平台集群不可用，当前状态 %s。
INTERNALERROR_CPCLUSTERUNAVAILABLE = 'InternalError.CpClusterUnavailable'

# 命令下放失败。
INTERNALERROR_CVMCAEMASTERDISPATCHERROR = 'InternalError.CvmCaeMasterDispatchError'

# MASTER通道查询失败。
INTERNALERROR_CVMCAEMASTERNONALIVE = 'InternalError.CvmCaeMasterNonAlive'

# 网关通用异常:%s。
INTERNALERROR_GATEWAYCOMMONERROR = 'InternalError.GatewayCommonError'

# 数据一致性异常:%s。
INTERNALERROR_GATEWAYCONSISTENCYERROR = 'InternalError.GatewayConsistencyError'

# 配置中心访问异常。
INTERNALERROR_GATEWAYCONSULERROR = 'InternalError.GatewayConsulError'

# 网关数据异常。
INTERNALERROR_GATEWAYDBERROR = 'InternalError.GatewayDbError'

# 部署组通用异常。
INTERNALERROR_GROUPCOMMONERROR = 'InternalError.GroupCommonError'

# 部署组操作请求MASTER 操作失败。
INTERNALERROR_GROUPMASTERNUKNOWNERROR = 'InternalError.GroupMasterNuknownError'

# TSF节点管理通用错误信息。
INTERNALERROR_INSTANCECOMMONERROR = 'InternalError.InstanceCommonError'

# 创建kubernetes秘钥失败。
INTERNALERROR_KUBERNETESAPICREATESECRETERROR = 'InternalError.KubernetesApiCreateSecretError'

# kubernetes api 调用失败。
INTERNALERROR_KUBERNETESCALLERROR = 'InternalError.KubernetesCallError'

# 远程调用失败。
INTERNALERROR_REMOTESERVICECALLERROR = 'InternalError.RemoteServiceCallError'

# 仓库内部错误。
INTERNALERROR_RUNTIMEERROR = 'InternalError.RuntimeError'

# IN子句中超过1000个候选项。
INTERNALERROR_SQLTOOMANYINITEM = 'InternalError.SqlTooManyInItem'

# 任务内部异常。
INTERNALERROR_TASKINTERNALERROR = 'InternalError.TaskInternalError'

# 调用 TKE 接口失败，%s。
INTERNALERROR_TKEAPIFAILEDOPERATION = 'InternalError.TkeApiFailedOperation'

# TSF应用性能管理ES客户端响应状态异常。
INTERNALERROR_TSFAPMESRESPONSESTATUSEXCEPTION = 'InternalError.TsfApmEsResponseStatusException'

# [%s]模块未处理异常。。
INTERNALERROR_UNHANDLEDEXCEPTION = 'InternalError.UnhandledException'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# [%s]模块接口[%s]请求不正确（400 BAD REQUEST）。。
INVALIDPARAMETER_BADREQUEST = 'InvalidParameter.BadRequest'

# TSF MASTER 实例状态异常。
INVALIDPARAMETER_CVMCAEMASTERUNKNOWNINSTANCESTATUS = 'InvalidParameter.CvmCaeMasterUnknownInstanceStatus'

# 参数错误。
INVALIDPARAMETER_KUBERNETESPARAMERROR = 'InvalidParameter.KubernetesParamError'

# 已经绑定灰度规则，无法删除。
INVALIDPARAMETER_LANEINFOALREADYUSED = 'InvalidParameter.LaneInfoAlreadyUsed'

# 存在同名的泳道。
INVALIDPARAMETER_LANEINFONAMEALREADYUSED = 'InvalidParameter.LaneInfoNameAlreadyUsed'

# 泳道名称格式有误。
INVALIDPARAMETER_LANEINFONAMEINVALID = 'InvalidParameter.LaneInfoNameInvalid'

# 泳道名称不能为空。
INVALIDPARAMETER_LANEINFONAMENOTEMPTY = 'InvalidParameter.LaneInfoNameNotEmpty'

# 泳道名称不能超过60个字符。
INVALIDPARAMETER_LANEINFONAMETOOLONG = 'InvalidParameter.LaneInfoNameTooLong'

# 泳道不存在。
INVALIDPARAMETER_LANEINFONOTEXIST = 'InvalidParameter.LaneInfoNotExist'

# 泳道没有设置任何入口应用。
INVALIDPARAMETER_LANEINFONOTEXISTENTRANCE = 'InvalidParameter.LaneInfoNotExistEntrance'

# 泳道备注不能超过200个字符。
INVALIDPARAMETER_LANEINFOREMARKTOOLONG = 'InvalidParameter.LaneInfoRemarkTooLong'

# 泳道规则中的泳道不存在。
INVALIDPARAMETER_LANERULEINFONOTEXIST = 'InvalidParameter.LaneRuleInfoNotExist'

# 存在同名的泳道规则名称。
INVALIDPARAMETER_LANERULENAMEALREADYUSED = 'InvalidParameter.LaneRuleNameAlreadyUsed'

# 泳道规则名称格式有误。
INVALIDPARAMETER_LANERULENAMEINVALID = 'InvalidParameter.LaneRuleNameInvalid'

# 泳道规则名称不能为空。
INVALIDPARAMETER_LANERULENAMENOTEMPTY = 'InvalidParameter.LaneRuleNameNotEmpty'

# 泳道规则名称不能超过60个字符。
INVALIDPARAMETER_LANERULENAMETOOLONG = 'InvalidParameter.LaneRuleNameTooLong'

# 泳道规则不存在。
INVALIDPARAMETER_LANERULENOTEXIST = 'InvalidParameter.LaneRuleNotExist'

# 泳道规则备注不能超过200个字符。
INVALIDPARAMETER_LANERULEREMARKTOOLONG = 'InvalidParameter.LaneRuleRemarkTooLong'

# 泳道规则标签名不能为空。
INVALIDPARAMETER_LANERULETAGNAMENOTEMPTY = 'InvalidParameter.LaneRuleTagNameNotEmpty'

# 泳道规则标签名不能超过32个字符。
INVALIDPARAMETER_LANERULETAGNAMETOOLONG = 'InvalidParameter.LaneRuleTagNameTooLong'

# 泳道规则必须设置至少一个标签。
INVALIDPARAMETER_LANERULETAGNOTEMPTY = 'InvalidParameter.LaneRuleTagNotEmpty'

# 泳道规则标签值不能超过128个字符。
INVALIDPARAMETER_LANERULETAGVALUETOOLONG = 'InvalidParameter.LaneRuleTagValueTooLong'

# 泳道规则总标签值不能超过200个字符。
INVALIDPARAMETER_LANERULETAGVALUETOTALTOOLONG = 'InvalidParameter.LaneRuleTagValueTotalTooLong'

# 包正在被使用，请先解除占用。
INVALIDPARAMETER_PACKAGEINUSE = 'InvalidParameter.PackageInUse'

# 参数错误。
INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'

# 请求参数有误。
INVALIDPARAMETER_REPOPACKAGEPARAMERROR = 'InvalidParameter.RepoPackageParamError'

# 仓库中存在软件包，请先删除软件包。
INVALIDPARAMETER_REPOSITORYNOTEMPTY = 'InvalidParameter.RepositoryNotEmpty'

# TSF应用性能管理业务日志配置与应用关联参数错误。
INVALIDPARAMETER_TSFAPMBUSILOGCFGAPPRELATIONPARAMERROR = 'InvalidParameter.TsfApmBusiLogCfgAppRelationParamError'

# TSF应用性能管理业务日志搜索请求参数错误。
INVALIDPARAMETER_TSFAPMBUSILOGSEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmBusiLogSearchRequestParamError'

# TSF应用性能管理标准输出日志搜索请求参数错误。
INVALIDPARAMETER_TSFAPMSTDOUTSEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmStdoutSearchRequestParamError'

# 仓库批量删除包数量超过单次允许上限。
INVALIDPARAMETER_UPPERDELETELIMIT = 'InvalidParameter.UpperDeleteLimit'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 所属应用ID不能为空。
INVALIDPARAMETERVALUE_APPLICATIONIDNULL = 'InvalidParameterValue.ApplicationIdNull'

# 无效的微服务类型。
INVALIDPARAMETERVALUE_APPLICATIONMICROTYPEINVALID = 'InvalidParameterValue.ApplicationMicroTypeInvalid'

# 应用名称已存在，请更换其他名称。
INVALIDPARAMETERVALUE_APPLICATIONNAMEEXIST = 'InvalidParameterValue.ApplicationNameExist'

# 应用名称不能为空。
INVALIDPARAMETERVALUE_APPLICATIONNAMENULL = 'InvalidParameterValue.ApplicationNameNull'

# 应用名称格式不正确,只能包含小写字母、数字及分隔符("_"、"-")，且不能以分隔符开头或结尾。
INVALIDPARAMETERVALUE_APPLICATIONNAMEREGXINVALID = 'InvalidParameterValue.ApplicationNameRegxInvalid'

# 无法获取应用。
INVALIDPARAMETERVALUE_APPLICATIONNOTEXISTS = 'InvalidParameterValue.ApplicationNotExists'

# 无效的应用分页参数。
INVALIDPARAMETERVALUE_APPLICATIONPAGELIMITINVALID = 'InvalidParameterValue.ApplicationPageLimitInvalid'

# 无效的应用类型。
INVALIDPARAMETERVALUE_APPLICATIONTYPEINVALID = 'InvalidParameterValue.ApplicationTypeInvalid'

# 与同VPC其它集群CIDR冲突。
INVALIDPARAMETERVALUE_CLUSTERCIDRCONFLICT = 'InvalidParameterValue.ClusterCidrConflict'

# 集群命名已存在，请更换其他名称。
INVALIDPARAMETERVALUE_CLUSTERNAMEEXIST = 'InvalidParameterValue.ClusterNameExist'

# 集群命名不能为空。
INVALIDPARAMETERVALUE_CLUSTERNAMEREQUIRED = 'InvalidParameterValue.ClusterNameRequired'

# 创建集群，无效的地域字段。
INVALIDPARAMETERVALUE_CLUSTERREGIONINVALID = 'InvalidParameterValue.ClusterRegionInvalid'

# 非法集群类型。
INVALIDPARAMETERVALUE_CLUSTERTYPEINVALID = 'InvalidParameterValue.ClusterTypeInvalid'

# 创建集群，无效的可用区字段。
INVALIDPARAMETERVALUE_CLUSTERZONEINVALID = 'InvalidParameterValue.ClusterZoneInvalid'

# 配置项已经发布过。
INVALIDPARAMETERVALUE_CONFIGALREADYRELEASED = 'InvalidParameterValue.ConfigAlreadyReleased'

# 配置项已存在。
INVALIDPARAMETERVALUE_CONFIGEXISTS = 'InvalidParameterValue.ConfigExists'

# 配置项和部署组所属应用不一致。
INVALIDPARAMETERVALUE_CONFIGGROUPAPPLICATIONIDNOTMATCH = 'InvalidParameterValue.ConfigGroupApplicationIdNotMatch'

# 配置项名称不合规。
INVALIDPARAMETERVALUE_CONFIGNAMEINVALID = 'InvalidParameterValue.ConfigNameInvalid'

# 无法获取配置项或无权限访问。
INVALIDPARAMETERVALUE_CONFIGNOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValue.ConfigNotExistsOrPermissionDenied'

# 无法获取配置项发布信息。
INVALIDPARAMETERVALUE_CONFIGRELEASENOTEXISTS = 'InvalidParameterValue.ConfigReleaseNotExists'

# 配置格式不符合YAML要求。
INVALIDPARAMETERVALUE_CONFIGVALUEFORMATINVALID = 'InvalidParameterValue.ConfigValueFormatInvalid'

# 配置项值内容大小（%s）超过限制。
INVALIDPARAMETERVALUE_CONFIGVALUETOOLONG = 'InvalidParameterValue.ConfigValueTooLong'

# 配置项版本描述不合规。
INVALIDPARAMETERVALUE_CONFIGVERSIONDESCINVALID = 'InvalidParameterValue.ConfigVersionDescInvalid'

# 配置项版本不合规。
INVALIDPARAMETERVALUE_CONFIGVERSIONINVALID = 'InvalidParameterValue.ConfigVersionInvalid'

# 服务访问方式不能为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPACCESSTYPENULL = 'InvalidParameterValue.ContainergroupAccesstypeNull'

# 所属应用ID不能为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPAPPLICATIONIDNULL = 'InvalidParameterValue.ContainergroupApplicationIdNull'

# 集群 CPU 资源不足。
INVALIDPARAMETERVALUE_CONTAINERGROUPCPULIMITOVER = 'InvalidParameterValue.ContainergroupCpulimitOver'

# 部署组ID不能为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPIDNULL = 'InvalidParameterValue.ContainergroupGroupidNull'

# 部署组名不能大于60个字符。
INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPNAMELEGNTH = 'InvalidParameterValue.ContainergroupGroupnameLegnth'

# 部署组名称格式不正确,只能包含小写字母、数字及分隔符("-"),且必须以小写字母开头，数字或小写字母结尾。
INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPNAMEREGEXMATCHFALSE = 'InvalidParameterValue.ContainergroupGroupnameRegexMatchFalse'

# 实例数量不能为空或不合法。
INVALIDPARAMETERVALUE_CONTAINERGROUPINSTANCENUMINVALID = 'InvalidParameterValue.ContainergroupInstanceNumInvalid'

# CPU limit 和 request 不能同时为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPINVALIDCPUINFO = 'InvalidParameterValue.ContainergroupInvalidCpuInfo'

# 内存 limit 和 request 不能同时为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPINVALIDMEMINFO = 'InvalidParameterValue.ContainergroupInvalidMemInfo'

# 集群内存资源不足。
INVALIDPARAMETERVALUE_CONTAINERGROUPMEMLIMITOVER = 'InvalidParameterValue.ContainergroupMemlimitOver'

# 主机端口值非法。
INVALIDPARAMETERVALUE_CONTAINERGROUPNODEPORTINVALID = 'InvalidParameterValue.ContainergroupNodePortInvalid'

# 服务端口值非法。
INVALIDPARAMETERVALUE_CONTAINERGROUPPORTINVALID = 'InvalidParameterValue.ContainergroupPortInvalid'

# 协议值非法,限定:TCP/UDP。
INVALIDPARAMETERVALUE_CONTAINERGROUPPROTOCOLINVALID = 'InvalidParameterValue.ContainergroupProtocolInvalid'

# 协议端口不能为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPPROTOCOLPORTSNULL = 'InvalidParameterValue.ContainergroupProtocolPortsNull'

# 镜像仓库名与应用名不匹配。
INVALIDPARAMETERVALUE_CONTAINERGROUPREPONAMEINVALID = 'InvalidParameterValue.ContainergroupReponameInvalid'

# 容器端口不允许重复映射。
INVALIDPARAMETERVALUE_CONTAINERGROUPTARGETPORTSREPEAT = 'InvalidParameterValue.ContainergroupTargetPortsRepeat'

# 容器端口不能为空。
INVALIDPARAMETERVALUE_CONTAINERGROUPTARGETPORTNULL = 'InvalidParameterValue.ContainergroupTargetportNull'

# 更新间隔不能为空或者数值非法。
INVALIDPARAMETERVALUE_CONTAINERGROUPUPDATEIVLINVALID = 'InvalidParameterValue.ContainergroupUpdateivlInvalid'

# 找不到业务容器。
INVALIDPARAMETERVALUE_CONTAINERGROUPYAMLUSERCONTAINERNOTFOUND = 'InvalidParameterValue.ContainergroupYamlUserContainerNotFound'

# TSF MASTER 正在执行任务，请等待任务执行完成再下发新任务。
INVALIDPARAMETERVALUE_CVMCAEMASTERAGENTBUSY = 'InvalidParameterValue.CvmCaeMasterAgentBusy'

# 无可用实例。
INVALIDPARAMETERVALUE_CVMCAEMASTERAGENTNOTFOUND = 'InvalidParameterValue.CvmCaeMasterAgentNotFound'

# TSF MASTER 部署组中无云主机。
INVALIDPARAMETERVALUE_CVMCAEMASTERGROUPNOAGENT = 'InvalidParameterValue.CvmCaeMasterGroupNoAgent'

# 部署组不存在。
INVALIDPARAMETERVALUE_DEPLOYGROUPNOTEXISTS = 'InvalidParameterValue.DeployGroupNotExists'

# 文件配置项已经发布。
INVALIDPARAMETERVALUE_FILECONFIGALREADYRELEASED = 'InvalidParameterValue.FileConfigAlreadyReleased'

# 文件配置项已存在。
INVALIDPARAMETERVALUE_FILECONFIGEXISTS = 'InvalidParameterValue.FileConfigExists'

# 配置文件路径重复。
INVALIDPARAMETERVALUE_FILECONFIGEXISTSPATH = 'InvalidParameterValue.FileConfigExistsPath'

# 其他用户已发布此配置文件路径。
INVALIDPARAMETERVALUE_FILECONFIGEXISTSPATHOTHER = 'InvalidParameterValue.FileConfigExistsPathOther'

# 文件配置项文件路径不合规。
INVALIDPARAMETERVALUE_FILECONFIGFILEPATHINVALID = 'InvalidParameterValue.FileConfigFilePathInvalid'

# 文件配置项名称不合规。
INVALIDPARAMETERVALUE_FILECONFIGNAMEINVALID = 'InvalidParameterValue.FileConfigNameInvalid'

# 文件配置项版本描述不合规。
INVALIDPARAMETERVALUE_FILECONFIGVERSIONDESCINVALID = 'InvalidParameterValue.FileConfigVersionDescInvalid'

# 请求参数异常:%s。
INVALIDPARAMETERVALUE_GATEWAYPARAMETERERROR = 'InvalidParameterValue.GatewayParameterError'

# 无效请求参数:%s。
INVALIDPARAMETERVALUE_GATEWAYPARAMETERINVALID = 'InvalidParameterValue.GatewayParameterInvalid'

# 全局命名空间已经存在，只能创建一个全局命名空间。
INVALIDPARAMETERVALUE_GLOBALNAMESPACENAMEEXIST = 'InvalidParameterValue.GlobalNamespaceNameExist'

# 部署相关请求参数校验失败。
INVALIDPARAMETERVALUE_GROUPBATCHPARAMETERINVALID = 'InvalidParameterValue.GroupBatchParameterInvalid'

# 部署组的集群未绑定该命名空间。
INVALIDPARAMETERVALUE_GROUPCLUSTERNAMESPACENOTBOUND = 'InvalidParameterValue.GroupClusterNamespaceNotBound'

# 部署组ID不能为空。
INVALIDPARAMETERVALUE_GROUPIDNULL = 'InvalidParameterValue.GroupIdNull'

# 部署组名称已存在，请更换其他名称。
INVALIDPARAMETERVALUE_GROUPNAMEEXIST = 'InvalidParameterValue.GroupNameExist'

# 部署组名不能大于50个字符。
INVALIDPARAMETERVALUE_GROUPNAMELENGTH = 'InvalidParameterValue.GroupNameLength'

# 部署组名不能为空。
INVALIDPARAMETERVALUE_GROUPNAMENULL = 'InvalidParameterValue.GroupNameNull'

# 部署组名称格式不正确,只能包含小写字母、数字及分隔符("-"),且必须以小写字母开头，数字或小写字母结尾。
INVALIDPARAMETERVALUE_GROUPNAMEREGXMISMATCH = 'InvalidParameterValue.GroupNameRegxMismatch'

# 无法获取部署组。
INVALIDPARAMETERVALUE_GROUPNOTEXISTS = 'InvalidParameterValue.GroupNotExists'

# 分组无效的分业参数。
INVALIDPARAMETERVALUE_GROUPPAGELIMITINVALID = 'InvalidParameterValue.GroupPageLimitInvalid'

# 程序包不能为空。
INVALIDPARAMETERVALUE_GROUPPKGNULL = 'InvalidParameterValue.GroupPkgNull'

# 无效的部署组状态过滤字段。
INVALIDPARAMETERVALUE_GROUPSTATUSINVALID = 'InvalidParameterValue.GroupStatusInvalid'

# 分组操作，无有效机器。
INVALIDPARAMETERVALUE_GROUPVALIDINSTANCENULL = 'InvalidParameterValue.GroupValidInstanceNull'

# 镜像仓库名不合法,示例:tsf-repo/nginx。
INVALIDPARAMETERVALUE_IMAGEREPOREPONAMEINVALID = 'InvalidParameterValue.ImagerepoReponameInvalid'

# 镜像仓库名不能为空。
INVALIDPARAMETERVALUE_IMAGEREPOREPONAMENULL = 'InvalidParameterValue.ImagerepoReponameNull'

# imageTags不能为空。
INVALIDPARAMETERVALUE_IMAGEREPOTAGNAMENULL = 'InvalidParameterValue.ImagerepoTagnameNull'

# 重装系统，无效的镜像id。
INVALIDPARAMETERVALUE_INSTANCEINVALIDIMAGE = 'InvalidParameterValue.InstanceInvalidImage'

# 参数格式异常。
INVALIDPARAMETERVALUE_INVALIDPARAMETERFORMAT = 'InvalidParameterValue.InvalidParameterFormat'

# 已经绑定灰度规则，无法删除。
INVALIDPARAMETERVALUE_LANEINFOALREADYUSED = 'InvalidParameterValue.LaneInfoAlreadyUsed'

# 存在同名的泳道。
INVALIDPARAMETERVALUE_LANEINFONAMEALREADYUSED = 'InvalidParameterValue.LaneInfoNameAlreadyUsed'

# 泳道名称格式有误。
INVALIDPARAMETERVALUE_LANEINFONAMEINVALID = 'InvalidParameterValue.LaneInfoNameInvalid'

# 泳道名称不能为空。
INVALIDPARAMETERVALUE_LANEINFONAMENOTEMPTY = 'InvalidParameterValue.LaneInfoNameNotEmpty'

# 泳道名称不能超过60个字符。
INVALIDPARAMETERVALUE_LANEINFONAMETOOLONG = 'InvalidParameterValue.LaneInfoNameTooLong'

# 泳道不存在。
INVALIDPARAMETERVALUE_LANEINFONOTEXIST = 'InvalidParameterValue.LaneInfoNotExist'

# 泳道没有设置任何入口应用。
INVALIDPARAMETERVALUE_LANEINFONOTEXISTENTRANCE = 'InvalidParameterValue.LaneInfoNotExistEntrance'

# 泳道备注不能超过200个字符。
INVALIDPARAMETERVALUE_LANEINFOREMARKTOOLONG = 'InvalidParameterValue.LaneInfoRemarkTooLong'

# 全链路灰度规则中的泳道不存在。
INVALIDPARAMETERVALUE_LANERULEINFONOTEXIST = 'InvalidParameterValue.LaneRuleInfoNotExist'

# 存在同名的全链路灰度规则。
INVALIDPARAMETERVALUE_LANERULENAMEALREADYUSED = 'InvalidParameterValue.LaneRuleNameAlreadyUsed'

# 全链路灰度规则名称格式有误。
INVALIDPARAMETERVALUE_LANERULENAMEINVALID = 'InvalidParameterValue.LaneRuleNameInvalid'

# 全链路灰度规则名称不能为空。
INVALIDPARAMETERVALUE_LANERULENAMENOTEMPTY = 'InvalidParameterValue.LaneRuleNameNotEmpty'

# 全链路灰度规则名称不能超过60个字符。
INVALIDPARAMETERVALUE_LANERULENAMETOOLONG = 'InvalidParameterValue.LaneRuleNameTooLong'

# 全链路灰度规则不存在。
INVALIDPARAMETERVALUE_LANERULENOTEXIST = 'InvalidParameterValue.LaneRuleNotExist'

# 全链路灰度规则备注不能超过200个字符。
INVALIDPARAMETERVALUE_LANERULEREMARKTOOLONG = 'InvalidParameterValue.LaneRuleRemarkTooLong'

# 全链路灰度规则标签名不能为空。
INVALIDPARAMETERVALUE_LANERULETAGNAMENOTEMPTY = 'InvalidParameterValue.LaneRuleTagNameNotEmpty'

# 全链路灰度规则标签名不能超过32个字符。
INVALIDPARAMETERVALUE_LANERULETAGNAMETOOLONG = 'InvalidParameterValue.LaneRuleTagNameTooLong'

# 全链路灰度规则必须设置至少一个标签。
INVALIDPARAMETERVALUE_LANERULETAGNOTEMPTY = 'InvalidParameterValue.LaneRuleTagNotEmpty'

# 全链路灰度规则标签值不能超过128个字符。
INVALIDPARAMETERVALUE_LANERULETAGVALUETOOLONG = 'InvalidParameterValue.LaneRuleTagValueTooLong'

# 全链路灰度规则总标签值不能超过200个字符。
INVALIDPARAMETERVALUE_LANERULETAGVALUETOTALTOOLONG = 'InvalidParameterValue.LaneRuleTagValueTotalTooLong'

# 集群已关联该命名空间。
INVALIDPARAMETERVALUE_NAMESPACEALREADYBINDCLUSTER = 'InvalidParameterValue.NamespaceAlreadyBindCluster'

# 命名空间描格式不正确。
INVALIDPARAMETERVALUE_NAMESPACEDESCINVALID = 'InvalidParameterValue.NamespaceDescInvalid'

# 命名空间名称已存在，请更换其他名称。
INVALIDPARAMETERVALUE_NAMESPACENAMEEXIST = 'InvalidParameterValue.NamespaceNameExist'

# 命名空间名称格式不正确。
INVALIDPARAMETERVALUE_NAMESPACENAMEINVALID = 'InvalidParameterValue.NamespaceNameInvalid'

# 无法获取命名空间。
INVALIDPARAMETERVALUE_NAMESPACENOTEXISTS = 'InvalidParameterValue.NamespaceNotExists'

# 配置项已经发布，不允许删除。
INVALIDPARAMETERVALUE_RELEASEDCONFIGCANNOTBEDELETED = 'InvalidParameterValue.ReleasedConfigCanNotBeDeleted'

# 无权限操作资源%s。
INVALIDPARAMETERVALUE_RESOURCEPERMISSIONDENIED = 'InvalidParameterValue.ResourcePermissionDenied'

# ResourceType 不支持。
INVALIDPARAMETERVALUE_RESOURCETYPEERROR = 'InvalidParameterValue.ResourceTypeError'

# 服务描述不能大于200字符。
INVALIDPARAMETERVALUE_SERVICEDESCLENGTH = 'InvalidParameterValue.ServiceDescLength'

# 服务名称重复。
INVALIDPARAMETERVALUE_SERVICENAMEREPEATED = 'InvalidParameterValue.ServiceNameRepeated'

# 服务不存在或权限不足。
INVALIDPARAMETERVALUE_SERVICENOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValue.ServiceNotExistsOrPermissionDenied'

# 无效请求参数。
INVALIDPARAMETERVALUE_TASKPARAMETERINVALID = 'InvalidParameterValue.TaskParameterInvalid'

# 命名空间数达到上限。
LIMITEXCEEDED_ERRNAMESPACEMAXLIMIT = 'LimitExceeded.ErrNamespaceMaxLimit'

# 仓库达到上限。
LIMITEXCEEDED_ERRREPOMAXLIMIT = 'LimitExceeded.ErrRepoMaxLimit'

# 最多支持创建五个容器集群，当前已经超过使用上限。
LIMITEXCEEDED_TKECLUSTERNUMBEREXCEEDLIMIT = 'LimitExceeded.TkeClusterNumberExceedLimit'

# 应用ID不能为空。
MISSINGPARAMETER_APPLICATIONIDNULL = 'MissingParameter.ApplicationIdNull'

# 应用ID未填写。
MISSINGPARAMETER_APPLICATIONIDREQUIRED = 'MissingParameter.ApplicationIdRequired'

# 应用类型不能为空。
MISSINGPARAMETER_APPLICATIONTYPENULL = 'MissingParameter.ApplicationTypeNull'

# 集群所属子网不能为空。
MISSINGPARAMETER_CLUSTERSUBNETREQUIRED = 'MissingParameter.ClusterSubnetRequired'

# 配置项ID未填写。
MISSINGPARAMETER_CONFIGIDREQUIRED = 'MissingParameter.ConfigIdRequired'

# 配置项名称未填写。
MISSINGPARAMETER_CONFIGNAMEREQUIRED = 'MissingParameter.ConfigNameRequired'

# 配置项发布信息ID未填写。
MISSINGPARAMETER_CONFIGRELEASEIDREQUIRED = 'MissingParameter.ConfigReleaseIdRequired'

# 配置项类型未填写。
MISSINGPARAMETER_CONFIGTYPEREQUIRED = 'MissingParameter.ConfigTypeRequired'

# 配置项值未填写。
MISSINGPARAMETER_CONFIGVALUEREQUIRED = 'MissingParameter.ConfigValueRequired'

# 配置项版本未填写。
MISSINGPARAMETER_CONFIGVERSIONREQUIRED = 'MissingParameter.ConfigVersionRequired'

# 文件配置项文件内容未填写。
MISSINGPARAMETER_FILECONFIGFILEVALUEREQUIRED = 'MissingParameter.FileConfigFileValueRequired'

# 缺少请求参数:%s。
MISSINGPARAMETER_GATEWAYPARAMETERREQUIRED = 'MissingParameter.GatewayParameterRequired'

# 分组所属应用不能为空。
MISSINGPARAMETER_GROUPAPPLICATIONNULL = 'MissingParameter.GroupApplicationNull'

# 分组ID不能为空。
MISSINGPARAMETER_GROUPIDNULL = 'MissingParameter.GroupIdNull'

# 命名空间ID不能为空。
MISSINGPARAMETER_NAMESPACEIDREQUIRED = 'MissingParameter.NamespaceIdRequired'

# %s缺失。
MISSINGPARAMETER_REQUIREDPARAMETERMISSING = 'MissingParameter.RequiredParameterMissing'

# 未填写服务Id。
MISSINGPARAMETER_SERVICEIDREQUIRED = 'MissingParameter.ServiceIdRequired'

# 缺少必填参数。
MISSINGPARAMETER_TASKPARAMETERMISSED = 'MissingParameter.TaskParameterMissed'

# 此应用下存在资源，无法执行删除操作。
RESOURCEINUSE_APPLICATIONCANNOTDELETE = 'ResourceInUse.ApplicationCannotDelete'

# 资源仍在使用中 无法删除。
RESOURCEINUSE_CVMCAEMASTERCANNOTDELETE = 'ResourceInUse.CvmcaeMasterCannotDelete'

# 默认命名空间不能被删除。
RESOURCEINUSE_DEFAULTNAMEPSACECANNOTBEDELETED = 'ResourceInUse.DefaultNamepsaceCannotBeDeleted'

# 此分组下存在资源，无法执行删除操作。
RESOURCEINUSE_GROUPCANNOTDELETE = 'ResourceInUse.GroupCannotDelete'

# 部署组在更新中 请稍后再执行该操作。
RESOURCEINUSE_GROUPINOPERATION = 'ResourceInUse.GroupInOperation'

# 机器实例已经被使用。
RESOURCEINUSE_INSTANCEHASBEENUSED = 'ResourceInUse.InstanceHasBeenUsed'

# 此命名空间下存在资源，无法执行删除操作。
RESOURCEINUSE_NAMESPACECANNOTDELETE = 'ResourceInUse.NamespaceCannotDelete'

# 资源对象已存在。
RESOURCEINUSE_OBJECTEXIST = 'ResourceInUse.ObjectExist'

# 限流规则已存在，请检查规则名和规则配置。
RESOURCEINUSE_RATELIMITRULEEXISTERROR = 'ResourceInUse.RatelimitRuleExistError'

# 实例数已达上限。
RESOURCEINSUFFICIENT_INSTANCEEXCESSLIMIT = 'ResourceInsufficient.InstanceExcessLimit'

# 仓库空间达到上限。
RESOURCEINSUFFICIENT_PACKAGESPACEFULL = 'ResourceInsufficient.PackageSpaceFull'

# 无法获取应用信息。
RESOURCENOTFOUND_APPLICATIONNOTEXIST = 'ResourceNotFound.ApplicationNotExist'

# 应用不存在或应用不属于当前项目。
RESOURCENOTFOUND_APPLICATIONPROJECTNOTMATCH = 'ResourceNotFound.ApplicationProjectNotMatch'

# 无法获取命名空间所属集群。
RESOURCENOTFOUND_CLUSTERNOTEXIST = 'ResourceNotFound.ClusterNotExist'

# 集群所属私有网络不存在。
RESOURCENOTFOUND_CLUSTERVPCNOTEXIST = 'ResourceNotFound.ClusterVpcNotExist'

# 找不到集群。
RESOURCENOTFOUND_CONTAINERGROUPCLUSTERNOTFOUND = 'ResourceNotFound.ContainergroupClusterNotfound'

# 无法找到该部署组所属集群和命名空间。
RESOURCENOTFOUND_CONTAINERGROUPGROUPNAMESPACECLUSTERNOTFOUND = 'ResourceNotFound.ContainergroupGroupNamespaceClusterNotFound'

# 无法找到该部署组。
RESOURCENOTFOUND_CONTAINERGROUPGROUPNOTFOUND = 'ResourceNotFound.ContainergroupGroupNotFound'

# TSF MASTER 资源不存在。
RESOURCENOTFOUND_CVMCAEMASTERRESOURCENOTFOUND = 'ResourceNotFound.CvmcaeMasterResourceNotFound'

# 镜像仓库不存在。
RESOURCENOTFOUND_ERRNOREPO = 'ResourceNotFound.ErrNoRepo'

# 用户错误。
RESOURCENOTFOUND_ERRNOUSER = 'ResourceNotFound.ErrNoUser'

# 无法获取分组所属应用。
RESOURCENOTFOUND_GROUPAPPLICATIONNOTEXIST = 'ResourceNotFound.GroupApplicationNotExist'

# 无法获取分组所属命名空间。
RESOURCENOTFOUND_GROUPNAMESPACENOTEXIST = 'ResourceNotFound.GroupNamespaceNotExist'

# 此部署组不存在，无法执行该操作。
RESOURCENOTFOUND_GROUPNOTEXIST = 'ResourceNotFound.GroupNotExist'

# 无法获取机器信息。
RESOURCENOTFOUND_INSTANCENOTEXIST = 'ResourceNotFound.InstanceNotExist'

# 无法找到License服务器。
RESOURCENOTFOUND_LICENSESERVERNOTFOUND = 'ResourceNotFound.LicenseServerNotFound'

# 目标微服务已离线[%s]。。
RESOURCENOTFOUND_MICROSERVICEOFFLINE = 'ResourceNotFound.MicroserviceOffline'

# 无法获取命名空间。
RESOURCENOTFOUND_NAMESPACENOTEXIST = 'ResourceNotFound.NamespaceNotExist'

# 资源对象不存在。
RESOURCENOTFOUND_OBJECTNOEXIST = 'ResourceNotFound.ObjectNoExist'

# 无法获取服务，无法执行该操作。
RESOURCENOTFOUND_SERVICENOTEXIST = 'ResourceNotFound.ServiceNotExist'

# 任务不存在。
RESOURCENOTFOUND_TASKNOTFOUND = 'ResourceNotFound.TaskNotFound'

# TKE 中不存在该集群。
RESOURCENOTFOUND_TKECLUSTERNOTEXISTS = 'ResourceNotFound.TkeClusterNotExists'

# 访问 CAM 系统出错，%s。
UNAUTHORIZEDOPERATION_CAMGENERALERROR = 'UnauthorizedOperation.CamGeneralError'

# 协作者身份未授权，需要主账号授予协作者权限，参考 TSF 官网文档「快速入门/准备工作」。
UNAUTHORIZEDOPERATION_CAMTSFROLENOPERMISSION = 'UnauthorizedOperation.CamTsfRoleNoPermission'

# 当前主账号未创建TSF_QCSRole或未对子账号授予预设策略QcloudCamSubaccountsAuthorizeRoleFullAccess。请参考产品文档主账号协作者使用说明。。
UNAUTHORIZEDOPERATION_CAMTSFROLENOTEXIST = 'UnauthorizedOperation.CamTsfRoleNotExist'

# License未激活。。
UNAUTHORIZEDOPERATION_LICENSEINACTIVE = 'UnauthorizedOperation.LicenseInactive'

# 您所购买的服务不支持该操作。
UNAUTHORIZEDOPERATION_LICENSEUNAUTHORIZED = 'UnauthorizedOperation.LicenseUnauthorized'

# 缺少License。。
UNAUTHORIZEDOPERATION_NOLICENSE = 'UnauthorizedOperation.NoLicense'

# 用户无权限访问该接口。。
UNAUTHORIZEDOPERATION_NOPRIVILEGE = 'UnauthorizedOperation.NoPrivilege'

# 批量操作数量超过限制:%s。
UNSUPPORTEDOPERATION_GATEWAYTOOMANYREQUESTPARAMETER = 'UnsupportedOperation.GatewayTooManyRequestParameter'

# 操作不支持。
UNSUPPORTEDOPERATION_TASKNOTSUPPORTED = 'UnsupportedOperation.TaskNotSupported'

# 不支持的ACTION。。
UNSUPPORTEDOPERATION_UNSUPPORTACTION = 'UnsupportedOperation.UnsupportAction'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# HTTP请求错误。
FAILEDOPERATION_HTTPREQUESTERROR = 'FailedOperation.HttpRequestError'

# 资源不存在。
FAILEDOPERATION_NOTEXIST = 'FailedOperation.NotExist'

# 内部错误。
INTERNALERROR = 'InternalError'

# 使用的云存储错误。
INTERNALERROR_COSERROR = 'InternalError.CosError'

# 数据库操作错误。
INTERNALERROR_DBERROR = 'InternalError.DbError'

# 使用的消息队列错误。
INTERNALERROR_MQERROR = 'InternalError.MqError'

# 系统错误。
INTERNALERROR_SYSTEM = 'InternalError.System'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数错误。
INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'

# 禁止操作。
UNSUPPORTEDOPERATION_FORBIDOP = 'UnsupportedOperation.ForbidOp'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 帐号已欠费。
FAILEDOPERATION_ARREARSERROR = 'FailedOperation.ArrearsError'

# 今日次数达到限制。
FAILEDOPERATION_COUNTLIMITERROR = 'FailedOperation.CountLimitError'

# 检测失败。
FAILEDOPERATION_DETECTFAILED = 'FailedOperation.DetectFailed'

# 文件下载失败。
FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownLoadError'

# 图片内容为空。
FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'

# 引擎识别超时。
FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout'

# 身份证信息不合法（身份证号、姓名字段校验非法等）。
FAILEDOPERATION_IDCARDINFOILLEGAL = 'FailedOperation.IdCardInfoIllegal'

# 图片模糊。
FAILEDOPERATION_IMAGEBLUR = 'FailedOperation.ImageBlur'

# 图片解码失败。
FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'

# 照片未检测到名片。
FAILEDOPERATION_IMAGENOBUSINESSCARD = 'FailedOperation.ImageNoBusinessCard'

# 图片中未检测到身份证。
FAILEDOPERATION_IMAGENOIDCARD = 'FailedOperation.ImageNoIdCard'

# 图片中未检测到文本。
FAILEDOPERATION_IMAGENOTEXT = 'FailedOperation.ImageNoText'

# 图片尺寸过大，请参考输出参数中关于图片大小限制的说明。
FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'

# 发票数据不一致。
FAILEDOPERATION_INVOICEMISMATCH = 'FailedOperation.InvoiceMismatch'

# 输入的Language不支持。
FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'

# 照片中存在多张卡。
FAILEDOPERATION_MULTICARDERROR = 'FailedOperation.MultiCardError'

# 非香港身份证。
FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'

# 非马来身份证。
FAILEDOPERATION_NOMASIDCARD = 'FailedOperation.NoMASIDCard'

# 非护照。
FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'

# OCR识别失败。
FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'

# 查询无记录。
FAILEDOPERATION_QUERYNORECORD = 'FailedOperation.QueryNoRecord'

# 未知错误。
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'

# 服务未开通。
FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'

# 内部错误。
INTERNALERROR = 'InternalError'

# Config不是有效的JSON格式。
INVALIDPARAMETER_CONFIGFORMATERROR = 'InvalidParameter.ConfigFormatError'

# 图片解码失败。
INVALIDPARAMETER_ENGINEIMAGEDECODEFAILED = 'InvalidParameter.EngineImageDecodeFailed'

# 无效的GTIN。
INVALIDPARAMETER_INVALIDGTINERROR = 'InvalidParameter.InvalidGTINError'

# 参数值错误。
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'

# 文件内容太大。
LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'

# 发票不存在。
RESOURCENOTFOUND_NOINVOICE = 'ResourceNotFound.NoInvoice'

# 不支持当天发票查询。
RESOURCENOTFOUND_NOTSUPPORTCURRENTINVOICEQUERY = 'ResourceNotFound.NotSupportCurrentInvoiceQuery'

# 计费状态异常。
RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.dts.v20180330 import models


class DtsClient(AbstractClient):
    _apiVersion = '2018-03-30'
    _endpoint = 'dts.tencentcloudapi.com'
    _service = 'dts'


    def ActivateSubscribe(self, request):
        """本接口用于配置数据订阅，只有在未配置状态的订阅实例才能调用此接口。

        :param request: Request instance for ActivateSubscribe.
        :type request: :class:`tencentcloud.dts.v20180330.models.ActivateSubscribeRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ActivateSubscribeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ActivateSubscribe", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ActivateSubscribeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CompleteMigrateJob(self, request):
        """本接口（CompleteMigrateJob）用于完成数据迁移任务。
        选择采用增量迁移方式的任务, 需要在迁移进度进入准备完成阶段后, 调用本接口, 停止迁移增量数据。
        通过DescribeMigrateJobs接口查询到任务的状态为准备完成（status=8）时，此时可以调用本接口完成迁移任务。

        :param request: Request instance for CompleteMigrateJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.CompleteMigrateJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.CompleteMigrateJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CompleteMigrateJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CompleteMigrateJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateMigrateCheckJob(self, request):
        """创建校验迁移任务
        在开始迁移前, 必须调用本接口创建校验, 且校验成功后才能开始迁移. 校验的结果可以通过DescribeMigrateCheckJob查看.
        校验成功后,迁移任务若有修改, 则必须重新创建校验并通过后, 才能开始迁移.

        :param request: Request instance for CreateMigrateCheckJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.CreateMigrateCheckJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.CreateMigrateCheckJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateMigrateCheckJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateMigrateCheckJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateMigrateJob(self, request):
        """本接口（CreateMigrateJob）用于创建数据迁移任务。

        如果是金融区链路, 请使用域名: dts.ap-shenzhen-fsi.tencentcloudapi.com

        :param request: Request instance for CreateMigrateJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.CreateMigrateJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.CreateMigrateJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateMigrateJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateMigrateJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateSubscribe(self, request):
        """本接口(CreateSubscribe)用于创建一个数据订阅实例。

        :param request: Request instance for CreateSubscribe.
        :type request: :class:`tencentcloud.dts.v20180330.models.CreateSubscribeRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.CreateSubscribeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateSubscribe", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateSubscribeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteMigrateJob(self, request):
        """本接口（DeleteMigrationJob）用于删除数据迁移任务。当通过DescribeMigrateJobs接口查询到任务的状态为：检验中（status=3）、运行中（status=7）、准备完成（status=8）、撤销中（status=11）或者完成中（status=12）时，不允许删除任务。

        :param request: Request instance for DeleteMigrateJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.DeleteMigrateJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DeleteMigrateJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DeleteMigrateJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteMigrateJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeAsyncRequestInfo(self, request):
        """本接口（DescribeAsyncRequestInfo）用于查询任务执行结果

        :param request: Request instance for DescribeAsyncRequestInfo.
        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeAsyncRequestInfoRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeAsyncRequestInfoResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeAsyncRequestInfo", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeAsyncRequestInfoResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeMigrateCheckJob(self, request):
        """本接口用于创建校验后,获取校验的结果. 能查询到当前校验的状态和进度.
        若通过校验, 则可调用'StartMigrateJob' 开始迁移.
        若未通过校验, 则能查询到校验失败的原因. 请按照报错, 通过'ModifyMigrateJob'修改迁移配置或是调整源/目标实例的相关参数.

        :param request: Request instance for DescribeMigrateCheckJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeMigrateCheckJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeMigrateCheckJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeMigrateCheckJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeMigrateCheckJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeMigrateJobs(self, request):
        """查询数据迁移任务.
        如果是金融区链路, 请使用域名: https://dts.ap-shenzhen-fsi.tencentcloudapi.com

        :param request: Request instance for DescribeMigrateJobs.
        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeMigrateJobsRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeMigrateJobsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeMigrateJobs", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeMigrateJobsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeRegionConf(self, request):
        """本接口（DescribeRegionConf）用于查询可售卖订阅实例的地域

        :param request: Request instance for DescribeRegionConf.
        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeRegionConfRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeRegionConfResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeRegionConf", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeRegionConfResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeSubscribeConf(self, request):
        """本接口（DescribeSubscribeConf）用于查询订阅实例配置

        :param request: Request instance for DescribeSubscribeConf.
        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeSubscribeConfRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeSubscribeConfResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeSubscribeConf", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeSubscribeConfResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeSubscribes(self, request):
        """本接口(DescribeSubscribes)获取数据订阅实例信息列表，默认分页，每次返回20条

        :param request: Request instance for DescribeSubscribes.
        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeSubscribesRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeSubscribesResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeSubscribes", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeSubscribesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def IsolateSubscribe(self, request):
        """本接口（IsolateSubscribe）用于隔离小时计费的订阅实例。调用后，订阅实例将不能使用，同时停止计费。

        :param request: Request instance for IsolateSubscribe.
        :type request: :class:`tencentcloud.dts.v20180330.models.IsolateSubscribeRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.IsolateSubscribeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("IsolateSubscribe", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.IsolateSubscribeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyMigrateJob(self, request):
        """本接口（ModifyMigrateJob）用于修改数据迁移任务。
        当迁移任务处于下述状态时，允许调用本接口修改迁移任务：迁移创建中（status=1）、 校验成功(status=4)、校验失败(status=5)、迁移失败(status=10)。但源实例、目标实例类型和目标实例地域不允许修改。

        如果是金融区链路, 请使用域名: dts.ap-shenzhen-fsi.tencentcloudapi.com

        :param request: Request instance for ModifyMigrateJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.ModifyMigrateJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ModifyMigrateJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ModifyMigrateJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyMigrateJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifySubscribeAutoRenewFlag(self, request):
        """修改订阅实例自动续费标识

        :param request: Request instance for ModifySubscribeAutoRenewFlag.
        :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeAutoRenewFlagRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeAutoRenewFlagResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ModifySubscribeAutoRenewFlag", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifySubscribeAutoRenewFlagResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifySubscribeConsumeTime(self, request):
        """本接口(ModifySubscribeConsumeTime)用于修改数据订阅通道的消费时间点

        :param request: Request instance for ModifySubscribeConsumeTime.
        :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeConsumeTimeRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeConsumeTimeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ModifySubscribeConsumeTime", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifySubscribeConsumeTimeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifySubscribeName(self, request):
        """本接口(ModifySubscribeName)用于修改数据订阅实例的名称

        :param request: Request instance for ModifySubscribeName.
        :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeNameRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeNameResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ModifySubscribeName", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifySubscribeNameResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifySubscribeObjects(self, request):
        """本接口(ModifySubscribeObjects)用于修改数据订阅通道的订阅规则

        :param request: Request instance for ModifySubscribeObjects.
        :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeObjectsRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeObjectsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ModifySubscribeObjects", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifySubscribeObjectsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifySubscribeVipVport(self, request):
        """本接口(ModifySubscribeVipVport)用于修改数据订阅实例的IP和端口号

        :param request: Request instance for ModifySubscribeVipVport.
        :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeVipVportRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeVipVportResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ModifySubscribeVipVport", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifySubscribeVipVportResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def OfflineIsolatedSubscribe(self, request):
        """本接口（OfflineIsolatedSubscribe）用于下线已隔离的数据订阅实例

        :param request: Request instance for OfflineIsolatedSubscribe.
        :type request: :class:`tencentcloud.dts.v20180330.models.OfflineIsolatedSubscribeRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.OfflineIsolatedSubscribeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("OfflineIsolatedSubscribe", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.OfflineIsolatedSubscribeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ResetSubscribe(self, request):
        """本接口(ResetSubscribe)用于重置数据订阅实例，已经激活的数据订阅实例，重置后可以使用ActivateSubscribe接口绑定其他的数据库实例

        :param request: Request instance for ResetSubscribe.
        :type request: :class:`tencentcloud.dts.v20180330.models.ResetSubscribeRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.ResetSubscribeResponse`

        """
        try:
            params = request._serialize()
            body = self.call("ResetSubscribe", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ResetSubscribeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def StartMigrateJob(self, request):
        """本接口（StartMigrationJob）用于启动迁移任务。非定时迁移任务会在调用后立即开始迁移，定时任务则会开始倒计时。
        调用此接口前，请务必先使用CreateMigrateCheckJob校验数据迁移任务，并通过DescribeMigrateJobs接口查询到任务状态为校验通过（status=4）时，才能启动数据迁移任务。

        :param request: Request instance for StartMigrateJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.StartMigrateJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.StartMigrateJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("StartMigrateJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.StartMigrateJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def StopMigrateJob(self, request):
        """本接口（StopMigrateJob）用于撤销数据迁移任务。
        在迁移过程中允许调用该接口撤销迁移, 撤销迁移的任务会失败。通过DescribeMigrateJobs接口查询到任务状态为运行中（status=7）或准备完成（status=8）时，才能撤销数据迁移任务。

        :param request: Request instance for StopMigrateJob.
        :type request: :class:`tencentcloud.dts.v20180330.models.StopMigrateJobRequest`
        :rtype: :class:`tencentcloud.dts.v20180330.models.StopMigrateJobResponse`

        """
        try:
            params = request._serialize()
            body = self.call("StopMigrateJob", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.StopMigrateJobResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 另一个请求正在处理中，请稍后再试。
FAILEDOPERATION_ANOTHERREQUESTPROCESSING = 'FailedOperation.AnotherRequestProcessing'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 重复的工作组名称。
INVALIDPARAMETER_DUPLICATEGROUPNAME = 'InvalidParameter.DuplicateGroupName'

# 重复的用户名。
INVALIDPARAMETER_DUPLICATEUSERNAME = 'InvalidParameter.DuplicateUserName'

# 无效的描述信息。
INVALIDPARAMETER_INVALIDDESCRIPTION = 'InvalidParameter.InvalidDescription'

# 无效的容错策略。
INVALIDPARAMETER_INVALIDFAILURETOLERANCE = 'InvalidParameter.InvalidFailureTolerance'

# 无效的工作组Id。
INVALIDPARAMETER_INVALIDGROUPID = 'InvalidParameter.InvalidGroupId'

# 无效的Offset值。
INVALIDPARAMETER_INVALIDOFFSET = 'InvalidParameter.InvalidOffset'

# SQL解析失败。
INVALIDPARAMETER_INVALIDSQL = 'InvalidParameter.InvalidSQL'

# 不支持的排序类型。
INVALIDPARAMETER_INVALIDSORTBYTYPE = 'InvalidParameter.InvalidSortByType'

# 存储位置错误。
INVALIDPARAMETER_INVALIDSTORELOCATION = 'InvalidParameter.InvalidStoreLocation'

# 无效的用户名。
INVALIDPARAMETER_INVALIDUSERNAME = 'InvalidParameter.InvalidUserName'

# 无效的工作组名。
INVALIDPARAMETER_INVALIDWORKGROUPNAME = 'InvalidParameter.InvalidWorkGroupName'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 指定数据源连接没有找到。
RESOURCENOTFOUND_DATASOURCENOTFOUND = 'ResourceNotFound.DatasourceNotFound'

# 无法修改主账号。
UNSUPPORTEDOPERATION_MODIFYOWNERUNSUPPORTED = 'UnsupportedOperation.ModifyOwnerUnsupported'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.af.v20200226 import models


class AfClient(AbstractClient):
    _apiVersion = '2020-02-26'
    _endpoint = 'af.tencentcloudapi.com'
    _service = 'af'


    def DescribeAntiFraud(self, request):
        """天御反欺诈服务，主要应用于银行、证券、保险、消费金融等金融行业客户，通过腾讯的大数据风控能力，
        可以准确识别恶意用户信息，解决客户在支付、活动、理财，风控等业务环节遇到的欺诈威胁，降低企业
        的损失。

        :param request: Request instance for DescribeAntiFraud.
        :type request: :class:`tencentcloud.af.v20200226.models.DescribeAntiFraudRequest`
        :rtype: :class:`tencentcloud.af.v20200226.models.DescribeAntiFraudResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeAntiFraud", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeAntiFraudResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def GetAntiFraud(self, request):
        """反欺诈评分接口

        :param request: Request instance for GetAntiFraud.
        :type request: :class:`tencentcloud.af.v20200226.models.GetAntiFraudRequest`
        :rtype: :class:`tencentcloud.af.v20200226.models.GetAntiFraudResponse`

        """
        try:
            params = request._serialize()
            body = self.call("GetAntiFraud", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.GetAntiFraudResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def QueryAntiFraud(self, request):
        """天御反欺诈服务，主要应用于银行、证券、保险、消费金融等金融行业客户，通过腾讯的大数据风控能力，
        可以准确识别恶意用户信息，解决客户在支付、活动、理财，风控等业务环节遇到的欺诈威胁，降低企业
        的损失。

        :param request: Request instance for QueryAntiFraud.
        :type request: :class:`tencentcloud.af.v20200226.models.QueryAntiFraudRequest`
        :rtype: :class:`tencentcloud.af.v20200226.models.QueryAntiFraudResponse`

        """
        try:
            params = request._serialize()
            body = self.call("QueryAntiFraud", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.QueryAntiFraudResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)